==> xlniuxdata-vipgame-1.0.65-20170302.081605-68-sources.jar: com/xunlei/niux/data/vipgame/vo/Games.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * 游戏信息
 *
 * @author lin
 * @date 2012-9-12
 * @Descripter:
 *
 */
@Table(tableName = "games", pkFieldName = "seqId", pkFieldAssign = false)
public class Games {

    private Long seqId;
    private String gameId;
    private String gameNo;
    private String gameName;
    private String gameDesc;
    private String gameType;
    private String runStatus;
    private String officialWebSite;
    private String forumUrl;// 论坛地址
    private String coparnterId;
    private Long displayOrder;
    private String status;
    private String remark;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;
    private Boolean useTemplate;
    private Integer clientType;
    private Integer loadClientType;
    private Boolean hasBigFenQu;
    private String payUrl;
    private String simpleName;
    private Integer gameFeature;
    private Integer playLevel;
    private String picUrl;
    private String smallPicUrl;
    private Boolean isNew;
    private Boolean isHot;
    private Integer mobileGameType;
    private String recommendIndex;

    // 运营类型 0联运游戏1独代游戏
    private String runType;

    private String appSize;
    private Integer downloadNum;
    private String summary;
    private String packageName;

    // 增加：是否有礼包
    private Boolean hasGift;
    // 是否首发
    private Boolean isFirstPublish;
    // 是否H5小游戏（因H5小游戏 算在手游下）
    private Boolean isH5Game;

    // 特权标识，用于欢乐谷
    private Integer privilegeType;
    private String videoUrl;
    private String videoDetailPicUrl;

    private String coparnterMails;

    public Boolean getHasGift() {
        return hasGift;
    }

    public void setHasGift(Boolean hasGift) {
        this.hasGift = hasGift;
    }

    public String getRunType() {
        return runType;
    }

    public void setRunType(String runType) {
        this.runType = runType;
    }

    public String getRecommendIndex() {
        return recommendIndex;
    }

    public void setRecommendIndex(String recommendIndex) {
        this.recommendIndex = recommendIndex;
    }

    public Integer getMobileGameType() {
        return mobileGameType;
    }

    public void setMobileGameType(Integer mobileGameType) {
        this.mobileGameType = mobileGameType;
    }

    public Boolean getIsNew() {
        return isNew;
    }

    public void setIsNew(Boolean isNew) {
        this.isNew = isNew;
    }

    public Boolean getIsHot() {
        return isHot;
    }

    public void setIsHot(Boolean isHot) {
        this.isHot = isHot;
    }

    public Integer getGameFeature() {
        return gameFeature;
    }

    public void setGameFeature(Integer gameFeature) {
        this.gameFeature = gameFeature;
    }

    public Integer getPlayLevel() {
        return playLevel;
    }

    public void setPlayLevel(Integer playLevel) {
        this.playLevel = playLevel;
    }

    public Boolean getHasBigFenQu() {
        return hasBigFenQu;
    }

    public void setHasBigFenQu(Boolean hasBigFenQu) {
        this.hasBigFenQu = hasBigFenQu;
    }

    public Integer getClientType() {
        return clientType;
    }

    public void setClientType(Integer clientType) {
        this.clientType = clientType;
    }

    public Integer getLoadClientType() {
        return loadClientType;
    }

    public void setLoadClientType(Integer loadClientType) {
        this.loadClientType = loadClientType;
    }

    public Long getSeqId() {
        return seqId;
    }
    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }
    public String getGameId() {
        return gameId;
    }
    public void setGameId(String gameId) {
        this.gameId = gameId;
    }
    public String getGameNo() {
        return gameNo;
    }
    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }
    public String getGameName() {
        return gameName;
    }
    public void setGameName(String gameName) {
        this.gameName = gameName;
    }
    public String getGameDesc() {
        return gameDesc;
    }
    public void setGameDesc(String gameDesc) {
        this.gameDesc = gameDesc;
    }
    public String getGameType() {
        return gameType;
    }
    public void setGameType(String gameType) {
        this.gameType = gameType;
    }
    public String getRunStatus() {
        return runStatus;
    }
    public void setRunStatus(String runStatus) {
        this.runStatus = runStatus;
    }

    public String getOfficialWebSite() {
        return officialWebSite;
    }
    public void setOfficialWebSite(String officialWebSite) {
        this.officialWebSite = officialWebSite;
    }
    public String getForumUrl() {
        return forumUrl;
    }
    public void setForumUrl(String forumUrl) {
        this.forumUrl = forumUrl;
    }
    public String getCoparnterId() {
        return coparnterId;
    }
    public void setCoparnterId(String coparnterId) {
        this.coparnterId = coparnterId;
    }
    public Long getDisplayOrder() {
        return displayOrder;
    }
    public void setDisplayOrder(Long displayOrder) {
        this.displayOrder = displayOrder;
    }
    public String getStatus() {
        return status;
    }
    public void setStatus(String status) {
        this.status = status;
    }
    public String getRemark() {
        return remark;
    }
    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getInputBy() {
        return inputBy;
    }
    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }
    public String getInputTime() {
        return inputTime;
    }
    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }
    public String getEditBy() {
        return editBy;
    }
    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }
    public String getEditTime() {
        return editTime;
    }
    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }
    public Boolean getUseTemplate() {
        return useTemplate;
    }
    public void setUseTemplate(Boolean useTemplate) {
        this.useTemplate = useTemplate;
    }

    public String getPayUrl() {
        return payUrl;
    }

    public void setPayUrl(String payUrl) {
        this.payUrl = payUrl;
    }

    public String getSimpleName() {
        return simpleName;
    }

    public void setSimpleName(String simpleName) {
        this.simpleName = simpleName;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getSmallPicUrl() {
        return smallPicUrl;
    }

    public void setSmallPicUrl(String smallPicUrl) {
        this.smallPicUrl = smallPicUrl;
    }

    public String getAppSize() {
        return appSize;
    }

    public void setAppSize(String appSize) {
        this.appSize = appSize;
    }

    public Integer getDownloadNum() {
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum) {
        this.downloadNum = downloadNum;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public Integer getPrivilegeType() {
        return privilegeType;
    }

    public void setPrivilegeType(Integer privilegeType) {
        this.privilegeType = privilegeType;
    }

    public Boolean getIsFirstPublish() {
        return isFirstPublish;
    }

    public void setIsFirstPublish(Boolean firstPublish) {
        isFirstPublish = firstPublish;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public String getVideoDetailPicUrl() {
        return videoDetailPicUrl;
    }

    public void setVideoDetailPicUrl(String videoDetailPicUrl) {
        this.videoDetailPicUrl = videoDetailPicUrl;
    }

    public Boolean getIsH5Game() {
        return isH5Game;
    }

    public void setIsH5Game(Boolean h5Game) {
        isH5Game = h5Game;
    }

    public String getCoparnterMails() {
        return coparnterMails;
    }

    public void setCoparnterMails(String coparnterMails) {
        this.coparnterMails = coparnterMails;
    }

}

==> xlniuxdata-vipgame-1.0.65-20171114.063132-114-sources.jar: com/xunlei/niux/data/vipgame/vo/Games.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;

/**
 * 游戏信息
 *
 * @author lin
 * @date 2012-9-12
 * @Descripter:
 *
 */
@Table(tableName = "games", pkFieldName = "seqId", pkFieldAssign = false)
public class Games {

    private Long seqId;
    private String gameId;
    private String gameNo;
    private String gameName;
    private String gameDesc;
    private String gameType;
    private String runStatus;
    private String officialWebSite;
    private String forumUrl;// 论坛地址
    private String coparnterId;
    private Long displayOrder;
    private String status;
    private String remark;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;
    private Boolean useTemplate;
    private Integer clientType;
    private Integer loadClientType;
    private Boolean hasBigFenQu;
    private String payUrl;
    private String simpleName;
    private Integer gameFeature;
    @Exclude
    private String gameTrait;
    private Integer playLevel;
    private String picUrl;
    private String smallPicUrl;
    private Boolean isNew;
    private Boolean isHot;
    private Integer mobileGameType;
    private String recommendIndex;

    // 运营类型 0联运游戏1独代游戏
    private String runType;

    private String appSize;
    private Integer downloadNum;
    private String summary;
    private String packageName;

    // 增加：是否有礼包
    private Boolean hasGift;
    // 是否首发
    private Boolean isFirstPublish;
    // 是否H5小游戏（因H5小游戏 算在手游下）
    private Boolean isH5Game;

    // 特权标识，用于欢乐谷
    private Integer privilegeType;
    private String videoUrl;
    private String videoDetailPicUrl;

    private String coparnterMails;

    public String getGameTrait() {
		return gameTrait;
	}

	public void setGameTrait(String gameTrait) {
		this.gameTrait = gameTrait;
	}

	public Boolean getHasGift() {
        return hasGift;
    }

    public void setHasGift(Boolean hasGift) {
        this.hasGift = hasGift;
    }

    public String getRunType() {
        return runType;
    }

    public void setRunType(String runType) {
        this.runType = runType;
    }

    public String getRecommendIndex() {
        return recommendIndex;
    }

    public void setRecommendIndex(String recommendIndex) {
        this.recommendIndex = recommendIndex;
    }

    public Integer getMobileGameType() {
        return mobileGameType;
    }

    public void setMobileGameType(Integer mobileGameType) {
        this.mobileGameType = mobileGameType;
    }

    public Boolean getIsNew() {
        return isNew;
    }

    public void setIsNew(Boolean isNew) {
        this.isNew = isNew;
    }

    public Boolean getIsHot() {
        return isHot;
    }

    public void setIsHot(Boolean isHot) {
        this.isHot = isHot;
    }

    public Integer getGameFeature() {
        return gameFeature;
    }

    public void setGameFeature(Integer gameFeature) {
        this.gameFeature = gameFeature;
    }

    public Integer getPlayLevel() {
        return playLevel;
    }

    public void setPlayLevel(Integer playLevel) {
        this.playLevel = playLevel;
    }

    public Boolean getHasBigFenQu() {
        return hasBigFenQu;
    }

    public void setHasBigFenQu(Boolean hasBigFenQu) {
        this.hasBigFenQu = hasBigFenQu;
    }

    public Integer getClientType() {
        return clientType;
    }

    public void setClientType(Integer clientType) {
        this.clientType = clientType;
    }

    public Integer getLoadClientType() {
        return loadClientType;
    }

    public void setLoadClientType(Integer loadClientType) {
        this.loadClientType = loadClientType;
    }

    public Long getSeqId() {
        return seqId;
    }
    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }
    public String getGameId() {
        return gameId;
    }
    public void setGameId(String gameId) {
        this.gameId = gameId;
    }
    public String getGameNo() {
        return gameNo;
    }
    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }
    public String getGameName() {
        return gameName;
    }
    public void setGameName(String gameName) {
        this.gameName = gameName;
    }
    public String getGameDesc() {
        return gameDesc;
    }
    public void setGameDesc(String gameDesc) {
        this.gameDesc = gameDesc;
    }
    public String getGameType() {
        return gameType;
    }
    public void setGameType(String gameType) {
        this.gameType = gameType;
    }
    public String getRunStatus() {
        return runStatus;
    }
    public void setRunStatus(String runStatus) {
        this.runStatus = runStatus;
    }

    public String getOfficialWebSite() {
        return officialWebSite;
    }
    public void setOfficialWebSite(String officialWebSite) {
        this.officialWebSite = officialWebSite;
    }
    public String getForumUrl() {
        return forumUrl;
    }
    public void setForumUrl(String forumUrl) {
        this.forumUrl = forumUrl;
    }
    public String getCoparnterId() {
        return coparnterId;
    }
    public void setCoparnterId(String coparnterId) {
        this.coparnterId = coparnterId;
    }
    public Long getDisplayOrder() {
        return displayOrder;
    }
    public void setDisplayOrder(Long displayOrder) {
        this.displayOrder = displayOrder;
    }
    public String getStatus() {
        return status;
    }
    public void setStatus(String status) {
        this.status = status;
    }
    public String getRemark() {
        return remark;
    }
    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getInputBy() {
        return inputBy;
    }
    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }
    public String getInputTime() {
        return inputTime;
    }
    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }
    public String getEditBy() {
        return editBy;
    }
    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }
    public String getEditTime() {
        return editTime;
    }
    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }
    public Boolean getUseTemplate() {
        return useTemplate;
    }
    public void setUseTemplate(Boolean useTemplate) {
        this.useTemplate = useTemplate;
    }

    public String getPayUrl() {
        return payUrl;
    }

    public void setPayUrl(String payUrl) {
        this.payUrl = payUrl;
    }

    public String getSimpleName() {
        return simpleName;
    }

    public void setSimpleName(String simpleName) {
        this.simpleName = simpleName;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getSmallPicUrl() {
        return smallPicUrl;
    }

    public void setSmallPicUrl(String smallPicUrl) {
        this.smallPicUrl = smallPicUrl;
    }

    public String getAppSize() {
        return appSize;
    }

    public void setAppSize(String appSize) {
        this.appSize = appSize;
    }

    public Integer getDownloadNum() {
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum) {
        this.downloadNum = downloadNum;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public Integer getPrivilegeType() {
        return privilegeType;
    }

    public void setPrivilegeType(Integer privilegeType) {
        this.privilegeType = privilegeType;
    }

    public Boolean getIsFirstPublish() {
        return isFirstPublish;
    }

    public void setIsFirstPublish(Boolean firstPublish) {
        isFirstPublish = firstPublish;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public String getVideoDetailPicUrl() {
        return videoDetailPicUrl;
    }

    public void setVideoDetailPicUrl(String videoDetailPicUrl) {
        this.videoDetailPicUrl = videoDetailPicUrl;
    }

    public Boolean getIsH5Game() {
        return isH5Game;
    }

    public void setIsH5Game(Boolean h5Game) {
        isH5Game = h5Game;
    }

    public String getCoparnterMails() {
        return coparnterMails;
    }

    public void setCoparnterMails(String coparnterMails) {
        this.coparnterMails = coparnterMails;
    }

}
